#!/bin/bash

################################################################################
# ATTENZIONE! - Controllare la presenza dei comandi setSeeds e beamOn
# all'interno del macro file
################################################################################

#
# G4Parallel SimulationSetUp.sh
#
# Predispone l'esecuzione di una simulazione Geant4 attraverso
# diversi job paralleli

#
# Parametri
#
# macroFilePath:
#   path del file di macro relativo alla simulazione Geant4 
# workingDirectoryPath:
#   path completo della directory che conterra' una cartella
#   per ognuno dei job da eseguire in parallelo. Tale cartellax
#   dovra' gia' essere stata creata
# numberOfJobs: 
#   numero di jobs eseguiti in parallelo
# 

# Estrae i parametri dello script dalla linea di comando
macroFilePath=$1
workingDirectoryPath=$2
numberOfJobs=$3

# Effettua il controllo sul numero dei parametri.
# Se non corretto visualizza la corretta sintassi dello
# script e esce
if test $# -ne 3
then
   echo "Numero parametri non corretto" # <===
   echo "Sintassi:"
   exit
fi

# Controlla se il path del file di macro è correttamene
# specificato. In caso contrario visualizza un messaggio
# di errore e esce
if test ! -f "$macroFilePath"
then
   echo "Errore nell'apertura del macro file $macroFilePath" # <===
   exit
fi

# Crea la struttura dei job

# Se la working directory non esiste, segnala la condizione di errore
# e termina
# Se l'operazione fallisce visualizza un messaggio di errore ed esce.
if test ! -d $workingDirectoryPath
then
   echo "Working direcory non esistente"
   exit
fi

# Verifica l'esistenza dela riga del file di macro che setta 
# il numero degli eventi processati da ogni job
#echo beamString=$(grep "/run/beamOn" $macroFilePath 2>&1)
grep "/run/beamOn" "$macroFilePath"
if test $? -ne 0
then
   echo "Parametro beamOn non specificato"
   exit
fi

beamString=$(grep "/run/beamOn" "$macroFilePath" 2>&1)
if test -z "$beamString"
then
   echo "Parametro beamOnmalformato"
   exit
fi

# Estrae da tale riga il numero di
read beamCmd beamOn <<< $beamString

echo "beamCmd: $beamCmd" "beamOn: $beamOn"

if test "$beamCmd" != "/run/beamOn"
then
   echo "beamOn non specificato"
   exit
fi
exit

# Costruisce all'interno della working directory tante directory quante
# il numero dei job. Il nome di ogni cartella sara' costituito dal nome
# della working directory seguito da un numero progressivo compreso tra 
# 1 e il numero dei job

# Cancella il contenuto della working directory
rm -rf $workingDirectoryPath/*

# Estrae il nome della working directory dal suo path
workingDirectoryName=$(basename $workingDirectoryPath)

# Crea tutte le sottocartelle per i job
for index in $(seq 1 $numberOfJobs)
do
   mkdir  $workingDirectoryPath\/$workingDirectoryName"_$index"
done


# Estrae da tale riga il numero di
read beamCmd eventsNumber <<< $beamString

# Acquisce la riga del file di macro che setta il seed
randString=$(grep "/random/setSeeds" $macroFilePath 2>&1)
read randCmd baseSeed trailer <<< $randString

# Estrae nome macro file da workingDirectoryPath
macroFileName=$(basename $macroFilePath)

# Copia il file di macro in ognuna delle cartelle create per i job
# modificandone opportunamente il seed e il numero degli eventi
for index in $(seq 1 $numberOfJobs)
do
   cp $macroFilePath $workingDirectoryPath\/$workingDirectoryName"_$index"

   # Modifica il seed
   randStringNew="$randCmd $baseSeed"
   sed -i \
          "s|$randString|$randStringNew|g" \
          $workingDirectoryPath\/$workingDirectoryName"_$index/$macroFileName"

   # Aggiorna il seed
   baseSeed=$(expr $baseSeed + 1)

   # Modifica il numero degli eventi
   beamStringNew="$beamCmd $jobBeamOn"
   sed -i \
          "s|$beamString|$beamStringNew|g" \
          $workingDirectoryPath\/$workingDirectoryName"_$index/$macroFileName"


done

exit 0
