#!/bin/bash -e

#
# G4Parallel SimulationSetUp.sh
#
# Predispone l'esecuzione di una simulazione Geant4 attraverso
# diversi job paralleli

#
# Parametri
#
# macroFilePath:
#   path del file di macro relativo alla simulazione Geant4 
# workingDirectoryPath:
#   path completo della directory che conterra' una cartella
#   per ognuno dei job da eseguire in parallelo. Tale cartellax
#   dovra' gia' essere stata creata
# numberOfJobs: 
#   numero di jobs eseguiti in parallelo
# 

# Estrae i parametri dello script dalla linea di comando
macroFilePath=$1
workingDirectoryPath=$2
numberOfJobs=$3

# Effettua il controllo sul numero dei parametri.
# Se non corretto visualizza la corretta sintassi dello
# script e esce

# Controlla se il path del file di macro è correttamene
# specificato. In caso contrario visualizza un messaggio
# di errore e esce

# Controlla se il path dell'eseguibile è correttamente specificato.
# In caso contrario visualizza un messaggio di errore e esce

# Crea la struttura dei job

# Se la working directory non esiste, segnala la condizione di errore
# e termina
# Se l'operazione fallisce visualizza un messaggio di errore ed esce.
if test ! -d $workingDirectoryPath
then
   echo "Working direcory non esistente"
   exit
fi

# Costruisce all'interno della working directory tante directory quante
# il numero dei job. Il nome di ogni cartella sara' costituito dal nome
# della working directory seguito da un numero progressivo compreso tra 1
# il numero dei job

# Cancella il contenuto della working directory
rm -rf $workingDirectoryPath/*

# Estrae il nome della working directory dal suo path
workingDirectoryName=$(basename $workingDirectoryPath)
echo "Nome della working directory: "$workingDirectoryName

# Crea tutte le sottocartelle per i job
for index in $(seq 1 $numberOfJobs)
do
   mkdir  $workingDirectoryPath\/$workingDirectoryName"_$index"
echo $workingDirectoryName"_$index" 
done

# Copia il file di macro in ognuna delle cartelle create per i job
# modificandone opportunamente il seed e il numero degli eventi
for index in $(seq 1 $numberOfJobs)
do
   cp $macroFilePath $workingDirectoryPath\/$workingDirectoryName"_$index"

   # Modifica il seed

   # Acquisce la riga del file di macro che setta il seed
   randString=$(grep "/random/setSeeds" $macroFilePath 2>&1)
   randStringNew=$(cut -d' ' -f2 $randString)#" $index"
echo $randStringNew
exit

   # Da tale riga estrae l'intero assegnato al seed
   sed -i \
          "s|$randString|$randStringNew|g" \
          "$G4C_WorkDir/$G4C_WorkBase.$i/$G4C_MacBase"

done


exit
